@@ -80,6 +80,10 @@ class ModelRecord(_Record):
             self.physics_quality: float = data["physics_quality"]
             self.asset_bundle_sizes: Dict[str, int] = data["asset_bundle_sizes"]
             self.composite_object: bool = data["composite_object"]
+            if "volume" not in data:
+                self.volume: float = 0
+            else:
+                self.volume: float = data["volume"]
 
 
 class MaterialRecord(_Record):
@@ -184,6 +188,7 @@ class RobotRecord(_Record):
         self.source: str = data["source"]
         self.immovable: bool = data["immovable"]
         self.targets: dict = data["targets"]
+        self.ik: list = data["ik"]
 
 
 T = TypeVar("T", bound=_Record)
