@@ -324,7 +324,11 @@ class TDWUtils:
         :return A PIL image.
         """
 
-        return Image.open(io.BytesIO(images.get_image(index)))
+        pass_mask = images.get_pass_mask(index)
+        if pass_mask == "_depth" or pass_mask == "_depth_simple":
+            return Image.fromarray(TDWUtils.get_shaped_depth_pass(images=images, index=index))
+        else:
+            return Image.open(io.BytesIO(images.get_image(index)))
 
     @staticmethod
     def get_random_position_on_nav_mesh(c: Controller, width: float, length: float, x_e=0, z_e=0, bake=True, rng=random.uniform) -> Tuple[float, float, float]:
@@ -607,17 +611,24 @@ class TDWUtils:
                 "center": np.array(bounds.get_center(index))}
 
     @staticmethod
-    def get_bounds_extents(bounds: Bounds, index: int) -> np.array:
+    def get_bounds_extents(bounds: Union[Bounds, Dict[str, Dict[str, float]]], index: int = 0) -> np.array:
         """
-        :param bounds: Bounds output data.
-        :param index: The index in `bounds` of the target object.
+        :param bounds: Bounds output data or cached bounds data from a record (`record.bounds`).
+        :param index: The index in `bounds` of the target object. Ignored if `bounds` is a dictionary.
 
-        :return: The width (left to right), length (front to back), and height (top to bottom) of the bounds as a numpy array.
+        :return: The width (left to right), height (top to bottom), and length (front to back), of the bounds as a numpy array.
         """
 
-        return np.array([np.linalg.norm(np.array(bounds.get_left(index)) - np.array(bounds.get_right(index))),
-                         np.linalg.norm(np.array(bounds.get_front(index)) - np.array(bounds.get_back(index))),
-                         np.linalg.norm(np.array(bounds.get_top(index)) - np.array(bounds.get_bottom(index)))])
+        if isinstance(bounds, Bounds):
+            return np.array([np.linalg.norm(np.array(bounds.get_left(index)) - np.array(bounds.get_right(index))),
+                             np.linalg.norm(np.array(bounds.get_top(index)) - np.array(bounds.get_bottom(index))),
+                             np.linalg.norm(np.array(bounds.get_front(index)) - np.array(bounds.get_back(index)))])
+        elif isinstance(bounds, dict):
+            return np.array([np.linalg.norm(TDWUtils.vector3_to_array(bounds["left"]) - TDWUtils.vector3_to_array(bounds["right"])),
+                             np.linalg.norm(TDWUtils.vector3_to_array(bounds["top"]) - TDWUtils.vector3_to_array(bounds["bottom"])),
+                             np.linalg.norm(TDWUtils.vector3_to_array(bounds["front"]) - TDWUtils.vector3_to_array(bounds["back"]))])
+        else:
+            raise Exception(f"Invalid bounds data: {bounds}")
 
     @staticmethod
     def get_closest_position_in_bounds(origin: np.array, bounds: Bounds, index: int) -> np.array:
@@ -727,3 +738,21 @@ class TDWUtils:
         """
 
         return b / (1 << 20)
+
+    @staticmethod
+    def get_circle_mask(shape: Tuple[int, int], row: int, column: int, radius: int) -> np.array:
+        """
+        Get elements in an array within a circle.
+
+        :param shape: The shape of the source array as (rows, columns).
+        :param row: The row (axis 0) of the center of the circle.
+        :param column: The column (axis 1) of the circle.
+        :param radius: The radius of the circle in indices.
+
+        :return: A boolean array with shape `shape`. Elements that are True are within the circle.
+        """
+
+        # Source: https://www.semicolonworld.com/question/44279/how-to-apply-a-disc-shaped-mask-to-a-numpy-array
+        nx, ny = shape
+        oy, ox = np.ogrid[-row:nx - row, -column:ny - column]
+        return ox * ox + oy * oy <= radius * radius
